@@ -12,9 +12,9 @@ from xpander_sdk import (
     ToolCallResult,
     LLMProvider,
     SourceNodeType,
-    GraphItem
+    GraphItem,
 )
-from ...generic import get_sub_agent_id_from_oas_by_name
+from ...generic import get_sub_agent_id_from_oas_by_name, wait
 from .base import SDKAdapter
 import chainlit as cl
 from chainlit.data.base import BaseDataLayer
@@ -309,7 +309,7 @@ class ChainlitXpanderDataLayer(BaseDataLayer):
         """
         author: dict = self.thread_authors_cache.get(thread_id, None)
         if not author or author == None:
-            pass
+            return
 
         xpander = XpanderClient(
             api_key=getenv("AGENT_CONTROLLER_API_KEY", ""),
@@ -474,7 +474,6 @@ class ChainlitAdapter(SDKAdapter):
                             break
 
                 self.agent.memory.update_messages(updated_thread)
-                print(updated_thread)
 
         # Add the new task to the agent
         super().add_task(input, files, use_worker, thread_id)
@@ -523,7 +522,7 @@ class ChainlitAdapter(SDKAdapter):
         
         return tool_calls
 
-    async def process_tool_calls(self, run_id: str, tool_calls: Dict[int, ChainlitToolCallWithLLMResponse], on_node_enter: Optional[Callable], on_node_error: Optional[Callable], agent_custom_functions: list[GraphItem] = [], local_tools: Dict[str, Callable] = None) -> str | None:
+    async def process_tool_calls(self, is_sequence_agent: bool, sequence_agent_graph_items:List[GraphItem], reported_sequence_sub_agent_ids: set, run_id: str, tool_calls: Dict[int, ChainlitToolCallWithLLMResponse], on_node_enter: Optional[Callable], on_node_error: Optional[Callable], agent_custom_functions: list[GraphItem] = [], local_tools: Dict[str, Callable] = None) -> str | None:
         """
         Process tool calls by formatting their payloads and executing them.
 
@@ -585,6 +584,27 @@ class ChainlitAdapter(SDKAdapter):
             return next((gi for gi in agent_custom_functions if gi.name == tc.name or gi.name.replace(" ","_") == tc.name),None)
         
         await xpander_step.remove()
+        
+        # sequence - manually add the sub agents and report to parent
+        if is_sequence_agent and not self.agent.id in reported_sequence_sub_agent_ids:
+            reported_sequence_sub_agent_ids.add(self.agent.id)
+            sub_agent_graph_item = next((gi for gi in sequence_agent_graph_items if gi.item_id == self.agent.id),None)
+            if sub_agent_graph_item:
+                await on_node_enter(tool_call=ToolCall(name=self.agent.name,type=ToolCallType.XPANDER),graph_item=sub_agent_graph_item)
+            # sleep for animation to work
+            await wait(seconds=1)
+            
+            seq_sub_item= cl.Step(
+                type="tool",
+                parent_id=run_id,
+                show_input=False,
+                default_open=True,
+                name=self.agent.name,
+                id=run_id+"_"+self.agent.id
+            )
+            seq_sub_item.output=None
+            await seq_sub_item.send()
+        
         for raw_tool_call in tool_calls.values():
             tool_call = raw_tool_call.tool_call
             is_agent_end_tool = True if tool_call.name == AGENT_END_TOOL else False
@@ -637,6 +657,7 @@ class ChainlitAdapter(SDKAdapter):
             
             if is_sub_agent_root:
                 current_step.show_input = False
+                current_step.default_open = True
                 current_step.output = None
             
             
